import request from "@/utils/request";
import { AxiosPromise } from "axios";
import {
  DictTypeQuery,
  DictTypePageResult,
  DictTypeForm,
  DictQuery,
  DictForm,
  DictPageResult,
} from "./types";

/**
 * 字典类型分页列表
 *
 * @param queryParams
 */
export function getDictTypePage(
  queryParams: DictTypeQuery
): AxiosPromise<DictTypePageResult> {
  return request({
    url: "/system/dict/type/list",
    method: "get",
    params: queryParams,
  });
}
/** 查询字典数据列表*/
export function listData(query: any) {
  return request({
    url: "/system/dict/data/list",
    method: "get",
    params: query,
  });
}

export function listType(query: any) {
  return request({
    url: "/system/dict/type/list",
    method: "get",
    params: query,
  });
}
/** 查询字典类型详细*/
export function getType(dictId) {
  return request({
    url: "/system/dict/type/detail/" + dictId,
    method: "get",
  });
}
// 修改字典数据
export function updateData(data) {
  const businessId = data.businessId;
  return request({
    url: "/system/dict/data/update/" + businessId,
    method: "put",
    data: data,
    headers: {},
  });
}
/** 获取字典选择框列表*/
export function selectDictType(dictType: any) {
  return request({
    url: "/system/dict/data/type/" + dictType,
    method: "get",
  });
}
/**  导出字典类型*/
export function exportType(queryParams: DictTypeQuery) {
  return request({
    url: "/system/dict/type/export",
    method: "get",
    params: queryParams,
    responseType: "arraybuffer",
  });
}
// 下载字典数据导入模板
export function importTemplate(query) {
  return request({
    url: "/system/dict/data/importTemplate",
    method: "get",
    responseType: "arraybuffer",
    params: query,
  });
}
//导入字典数据信息
export function importExcel(data) {
  return request({
    url: "/system/dict/data/importDictData",
    method: "post",
    headers: {
      "Content-Type": "multipart/form-data",
    },
    transformRequest: [
      (data) => {
        return data;
      },
    ],
    data,
  });
}
// 下载错误文件
export function uploadFalseFile(params) {
  params = Qs.stringify(params);
  return request({
    url: "/system/user/downFalseFile",
    method: "post",
    data: params,
    responseType: "blob",
  });
}
// 导出字典数据
export function exportData(query) {
  return request({
    url: "/system/dict/data/export",
    method: "get",
    params: query,
    responseType: "arraybuffer",
  });
}
/** 修改字典类型*/
export function updateType(data: any) {
  const businessId = data.businessId;
  return request({
    url: "/system/dict/type/update/" + businessId,
    method: "put",
    data: data,
    headers: {},
  });
}
// 新增字典数据
export function addData(data) {
  return request({
    url: "/system/dict/data/add",
    method: "post",
    data: data,
    headers: {},
  });
}
/** 新增字典类型*/
export function addType(data: any) {
  return request({
    url: "/system/dict/type/add",
    method: "post",
    data: data,
    headers: {},
  });
}

/**
 * 字典类型表单数据
 *
 * @param id
 */
export function getDictTypeForm(dictId: number): AxiosPromise<DictTypeForm> {
  return request({
    url: "/system/dict/type/detail/" + dictId,
    method: "get",
  });
}
// 4.查询字典数据详细
export function getData(dictCode) {
  return request({
    url: "/system/dict/data/detail/" + dictCode,
    method: "get",
  });
}
/**
 * 新增字典类型
 *
 * @param data
 */
export function addDictType(data: DictTypeForm) {
  return request({
    url: "/api/v1/dict/types",
    method: "post",
    data: data,
  });
}

/**
 * 修改字典类型
 *
 * @param id
 * @param data
 */
export function updateDictType(id: number, data: DictTypeForm) {
  return request({
    url: "/api/v1/dict/types/" + id,
    method: "put",
    data: data,
  });
}

/**
 * 删除字典类型
 */
export function deleteDictTypes(dictId: string) {
  return request({
    url: "/system/dict/type/deleteLogical/" + dictId,
    method: "delete",
  });
}
/** 删除字典数据*/
export function delData(dictCode) {
  return request({
    url: "/system/dict/data/deleteLogical/" + dictCode,
    method: "delete",
    headers: {},
  });
}

/**
 * 获取字典类型的数据项
 *
 * @param typeCode 字典类型编码
 */
export function getDictOptions(typeCode: string): AxiosPromise<OptionType[]> {
  return request({
    url: "/api/v1/dict/" + typeCode + "/options",
    method: "get",
  });
}

/**
 * 字典分页列表
 */
export function getDictPage(
  queryParams: DictQuery
): AxiosPromise<DictPageResult> {
  return request({
    url: "/api/v1/dict/page",
    method: "get",
    params: queryParams,
  });
}

/**
 * 获取字典表单数据
 *
 * @param id
 */
export function getDictFormData(id: number): AxiosPromise<DictForm> {
  return request({
    url: "/api/v1/dict/" + id + "/form",
    method: "get",
  });
}

/**
 * 新增字典
 *
 * @param data
 */
export function addDict(data: DictForm) {
  return request({
    url: "/api/v1/dict",
    method: "post",
    data: data,
  });
}

/**
 * 修改字典项
 *
 * @param id
 * @param data
 */
export function updateDict(id: number, data: DictForm) {
  return request({
    url: "/api/v1/dict/" + id,
    method: "put",
    data: data,
  });
}

/**
 * 删除字典
 *
 * @param ids 字典项ID，多个以英文逗号(,)分割
 */
export function deleteDict(ids: string) {
  return request({
    url: "/api/v1/dict/" + ids,
    method: "delete",
  });
}
